@@ -540,7 +540,6 @@ rebuild_dir (GVfsBackendOnedrive  *self,
   GList *items;
   GError *local_error = NULL;
   gint64 *timestamp;
-  g_autofree char *id = NULL;
 
   if (parent == self->shared_with_me_dir)
     {
@@ -560,8 +559,7 @@ rebuild_dir (GVfsBackendOnedrive  *self,
 
   timestamp = g_new (gint64, 1);
   *timestamp = g_get_real_time ();
-  id = get_full_item_id (parent);
-  g_hash_table_insert (self->dir_timestamps, id, timestamp);
+  g_hash_table_insert (self->dir_timestamps, get_full_item_id (parent), timestamp);
 
   for (GList *l = items; l != NULL; l = l->next)
     {
@@ -1908,7 +1906,15 @@ g_vfs_backend_onedrive_replace (GVfsBackend         *_self,
       insert_item (self, MSG_DRIVE_ITEM (new_item));
       g_hash_table_foreach (self->monitors, emit_create_event, item_path);
 
-      handle = write_handle_new (MSG_DRIVE_ITEM (new_item), NULL, filename, item_path);
+      stream = msg_drive_service_update (self->service, new_item, cancellable, &error);
+      if (error != NULL)
+        {
+          g_vfs_job_failed_from_error (G_VFS_JOB (job), error);
+          g_error_free (error);
+          goto out;
+        }
+
+      handle = write_handle_new (MSG_DRIVE_ITEM (new_item), stream, filename, item_path);
     }
 
   g_vfs_job_open_for_write_set_handle (job, handle);
