@@ -33,7 +33,7 @@
 
 #define SOCKET_NAME "wsdd"
 #define CONNECT_TIMEOUT 10
-#define LIST_COMMAND "list\n"
+#define LIST_COMMAND "list pub:Computer\n"
 #define PROBE_COMMAND "clear\nprobe\n"
 #define RELOAD_TIMEOUT 15
 #define PROBE_TIMEOUT 5
@@ -526,7 +526,7 @@ initable_init (GInitable *initable,
   const gchar *debug;
 
   debug = g_getenv ("GVFS_WSDD_DEBUG");
-  service->extra_debug = gvfs_get_debug ();
+  service->extra_debug = (debug != NULL);
 
   service->socket = g_socket_new (G_SOCKET_FAMILY_UNIX,
                                   G_SOCKET_TYPE_STREAM,
