@@ -386,11 +386,13 @@ update_volume (GVfsUDisks2Volume *volume)
               g_free (volume->name);
               volume->name = g_strdup (media_desc);
             }
+#ifdef HAVE_CDDA
           else if (volume->activation_root != NULL && g_file_has_uri_scheme (volume->activation_root, "cdda"))
             {
               g_free (volume->name);
               volume->name = g_strdup (_("Audio Disc"));
             }
+#endif
 
           volume->icon = media_icon != NULL ? g_object_ref (media_icon) : NULL;
           volume->symbolic_icon = media_symbolic_icon != NULL ? g_object_ref (media_symbolic_icon) : NULL;
@@ -624,6 +626,9 @@ on_udisks_client_changed (UDisksClient *client,
   GVfsUDisks2Volume *volume = GVFS_UDISKS2_VOLUME (user_data);
   MountData *data = NULL;
 
+  /* This is needed as gvfs_udisks2_volume_monitor_update may remove this volume. */
+  g_object_ref (volume);
+
   update_volume_on_event (volume);
 
   if (volume->mount_pending_op)
@@ -641,6 +646,8 @@ on_udisks_client_changed (UDisksClient *client,
           g_object_unref (cleartext_block);
         }
     }
+
+  g_object_unref (volume);
 }
 
 /* takes ownership of @mount_point if not NULL */
@@ -1496,13 +1503,14 @@ do_unlock (GTask *task)
                                                                        task);
           if (g_strcmp0 (type, "crypto_unknown") == 0)
             /* Translators: %s is the description of the volume that is being unlocked */
-            message = g_strdup_printf (_("Enter a passphrase to unlock the volume\n"
-                                         "The volume %s might be a VeraCrypt volume as it contains random data."),
+            message = g_strdup_printf (_("Authentication Required\n"
+                                         "A passphrase is needed to access encrypted data on “%s”.\n"
+                                         "The volume might be a VeraCrypt volume as it contains random data."),
                                        data->desc_of_encrypted_to_unlock);
           else
             /* Translators: %s is the description of the volume that is being unlocked */
-            message = g_strdup_printf (_("Enter a passphrase to unlock the volume\n"
-                                         "The passphrase is needed to access encrypted data on %s."),
+            message = g_strdup_printf (_("Authentication Required\n"
+                                         "A passphrase is needed to access encrypted data on “%s”."),
                                        data->desc_of_encrypted_to_unlock);
 
           pw_ask_flags = G_ASK_PASSWORD_NEED_PASSWORD | G_ASK_PASSWORD_SAVING_SUPPORTED;
